@@ -457,7 +457,7 @@ static int http_auth_basic_password_compare(server *srv, mod_auth_plugin_data *p
 		pam_handle_t *pamh=NULL;
 		int retval;
 		
-		retval = pam_start("login", username->ptr, &conv, &pamh);
+		retval = pam_start("lighttpd", username->ptr, &conv, &pamh);
 		
 		if (retval == PAM_SUCCESS)
 			retval = pam_authenticate(pamh, 0);    /* is user really user? */
@@ -850,7 +850,7 @@ int http_auth_digest_check(server *srv, connection *con, mod_auth_plugin_data *p
 	MD5_Update(&Md5Ctx, (unsigned char *)m, strlen(m));
 	MD5_Update(&Md5Ctx, (unsigned char *)":", 1);
 	MD5_Update(&Md5Ctx, (unsigned char *)uri, strlen(uri));
-	if (strcasecmp(qop, "auth-int") == 0) {
+	if (qop && strcasecmp(qop, "auth-int") == 0) {
 		MD5_Update(&Md5Ctx, (unsigned char *)":", 1);
 		MD5_Update(&Md5Ctx, (unsigned char *)"", HASHHEXLEN);
 	}
@@ -863,7 +863,7 @@ int http_auth_digest_check(server *srv, connection *con, mod_auth_plugin_data *p
 	MD5_Update(&Md5Ctx, (unsigned char *)":", 1);
 	MD5_Update(&Md5Ctx, (unsigned char *)nonce, strlen(nonce));
 	MD5_Update(&Md5Ctx, (unsigned char *)":", 1);
-	if (*qop) {
+	if (qop && *qop) {
 		MD5_Update(&Md5Ctx, (unsigned char *)nc, strlen(nc));
 		MD5_Update(&Md5Ctx, (unsigned char *)":", 1);
 		MD5_Update(&Md5Ctx, (unsigned char *)cnonce, strlen(cnonce));
@@ -879,7 +879,7 @@ int http_auth_digest_check(server *srv, connection *con, mod_auth_plugin_data *p
 		/* digest not ok */
 		
 		if (p->conf.auth_debug) {
-			log_error_write(srv, __FILE__, __LINE__, "ssssb", 
+			log_error_write(srv, __FILE__, __LINE__, "sss", 
 				"digest: digest mismatch", a2, respons);
 		}
 		
