@@ -750,8 +750,11 @@ static int fcgi_spawn_connection(server *srv,
 		
 		/* create socket */
 		if (-1 == bind(fcgi_fd, fcgi_addr, servlen)) {
-			log_error_write(srv, __FILE__, __LINE__, "ss", 
-				"bind failed:", strerror(errno));
+			log_error_write(srv, __FILE__, __LINE__, "sbds", 
+				"bind failed for:", 
+				proc->socket, 
+				proc->port, 
+				strerror(errno));
 			return -1;
 		}
 		
@@ -993,7 +996,7 @@ SETDEFAULTS_FUNC(mod_fastcgi_set_defaults) {
 						
 						{ "check-local",       NULL, T_CONFIG_BOOLEAN, T_CONFIG_SCOPE_CONNECTION },      /* 5 */
 						{ "port",              NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION },        /* 6 */
-						{ "min-procs",         NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION },        /* 7 */
+						{ "min-procs-not-working",         NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION },        /* 7 this is broken for now */
 						{ "max-procs",         NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION },        /* 8 */
 						{ "max-load-per-proc", NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION },        /* 9 */
 						{ "idle-timeout",      NULL, T_CONFIG_SHORT, T_CONFIG_SCOPE_CONNECTION },        /* 10 */
@@ -1093,6 +1096,9 @@ SETDEFAULTS_FUNC(mod_fastcgi_set_defaults) {
 					if (!buffer_is_empty(df->bin_path)) { 
 						/* a local socket + self spawning */
 						size_t pno;
+
+						/* HACK:  just to make sure the adaptive spawing is disabled */
+						df->min_procs = df->max_procs;
 						
 						if (df->min_procs > df->max_procs) df->max_procs = df->min_procs;
 						if (df->max_load_per_proc < 1) df->max_load_per_proc = 0;
@@ -1458,7 +1464,7 @@ static int fcgi_establish_connection(server *srv, handler_ctx *hctx) {
 		    errno == EINTR) {
 			if (hctx->conf.debug) {
 				log_error_write(srv, __FILE__, __LINE__, "sd", 
-						"connect delayed:", fcgi_fd);
+						"connect delayed, will continue later:", fcgi_fd);
 			}
 			
 			return 1;
@@ -2286,7 +2292,7 @@ static int fcgi_restart_dead_procs(server *srv, plugin_data *p, fcgi_extension_h
 			 */
 			
 			if ((proc->state == PROC_STATE_DISABLED) &&
-			    (srv->cur_ts - proc->disable_ts > FCGI_RETRY_TIMEOUT)) {
+			    (srv->cur_ts - proc->disable_ts > host->disable_time)) {
 				proc->state = PROC_STATE_RUNNING;
 				host->active_procs++;
 				
@@ -2336,6 +2342,14 @@ static int fcgi_restart_dead_procs(server *srv, plugin_data *p, fcgi_extension_h
 			    proc->load == 0) {
 				/* restart the child */
 				
+				if (p->conf.debug) {
+					log_error_write(srv, __FILE__, __LINE__, "ssdsbsdsd",
+							"--- fastcgi spawning",
+							"\n\tport:", host->port,
+							"\n\tsocket", host->unixsocket,
+							"\n\tcurrent:", 1, "/", host->min_procs);
+				}
+				
 				if (fcgi_spawn_connection(srv, p, host, proc)) {
 					log_error_write(srv, __FILE__, __LINE__, "s",
 							"ERROR: spawning fcgi failed.");
@@ -2360,8 +2374,17 @@ static handler_t fcgi_write_request(server *srv, handler_ctx *hctx) {
 
 	/* sanity check */	
 	if (!host ||
-	    ((!host->host->used || !host->port) && !host->unixsocket->used)) return HANDLER_ERROR;
+	    ((!host->host->used || !host->port) && !host->unixsocket->used)) {
+		log_error_write(srv, __FILE__, __LINE__, "sxddd", 
+				"write-req: error",
+				host,
+				host->host->used,
+				host->port,
+				host->unixsocket->used);
+		return HANDLER_ERROR;
+	}
 	
+
 	switch(hctx->state) {
 	case FCGI_STATE_INIT:
 		r = host->unixsocket->used ? AF_UNIX : AF_INET;
@@ -2442,7 +2465,7 @@ static handler_t fcgi_write_request(server *srv, handler_ctx *hctx) {
 				return HANDLER_ERROR;
 			}
 			if (socket_error != 0) {
-				if (!hctx->proc->is_local) {
+				if (!hctx->proc->is_local || p->conf.debug) {
 					/* local procs get restarted */
 					
 					log_error_write(srv, __FILE__, __LINE__, "ss",
@@ -2546,15 +2569,15 @@ static handler_t fcgi_write_request(server *srv, handler_ctx *hctx) {
 		hctx->write_offset += r;
 		
 		if (hctx->write_offset == hctx->write_buffer->used) {
+			/* we don't need the out event anymore */
+			fdevent_event_del(srv->ev, &(hctx->fde_ndx), hctx->fd);
+			fdevent_event_add(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_IN);
 			fcgi_set_state(srv, hctx, FCGI_STATE_READ);
 		}
 		
 		break;
 	case FCGI_STATE_READ:
 		/* waiting for a response */
-		
-		fdevent_event_add(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_IN);
-		
 		break;
 	default:
 		log_error_write(srv, __FILE__, __LINE__, "s", "(debug) unknown state");
@@ -2604,13 +2627,14 @@ SUBREQUEST_FUNC(mod_fastcgi_handle_subrequest) {
 			 * restart the request-handling 
 			 */
 			if (proc && proc->is_local) {
-#if 0
-				log_error_write(srv, __FILE__, __LINE__,  "sbdb", "connect() to fastcgi failed, restarting the request-handling:", 
-						host->host,
-						proc->port,
-						proc->socket);
-			
-#endif
+
+				if (p->conf.debug) {
+					log_error_write(srv, __FILE__, __LINE__,  "sbdb", "connect() to fastcgi failed, restarting the request-handling:", 
+							host->host,
+							proc->port,
+							proc->socket);
+				}
+
 				/* 
 				 * several hctx might reference the same proc
 				 * 
@@ -2632,6 +2656,7 @@ SUBREQUEST_FUNC(mod_fastcgi_handle_subrequest) {
 			
 			buffer_reset(con->physical.path);
 			con->mode = DIRECT;
+			joblist_append(srv, con);
 			
 			/* mis-using HANDLER_WAIT_FOR_FD to break out of the loop 
 			 * and hope that the childs will be restarted 
@@ -2656,6 +2681,7 @@ SUBREQUEST_FUNC(mod_fastcgi_handle_subrequest) {
 	case HANDLER_WAIT_FOR_FD:
 		return HANDLER_WAIT_FOR_FD;
 	default:
+		log_error_write(srv, __FILE__, __LINE__, "s", "subrequest write-req default");
 		return HANDLER_ERROR;
 	}
 }
@@ -2693,8 +2719,6 @@ static handler_t fcgi_handle_fdevent(void *s, void *ctx, int revents) {
 	fcgi_proc *proc   = hctx->proc;
 	fcgi_extension_host *host= hctx->host;
 
-	joblist_append(srv, con);
-	
 	if ((revents & FDEVENT_IN) &&
 	    hctx->state == FCGI_STATE_READ) {
 		switch (fcgi_demux_response(srv, hctx)) {
@@ -2724,6 +2748,7 @@ static handler_t fcgi_handle_fdevent(void *s, void *ctx, int revents) {
 				fcgi_connection_cleanup(srv, hctx);
 			}
 			
+			joblist_append(srv, con);
 			return HANDLER_FINISHED;
 		case -1:
 			if (proc->pid && proc->state != PROC_STATE_DIED) {
@@ -2753,6 +2778,14 @@ static handler_t fcgi_handle_fdevent(void *s, void *ctx, int revents) {
 								status);
 					}
 					
+					if (p->conf.debug) {
+						log_error_write(srv, __FILE__, __LINE__, "ssdsbsdsd",
+								"--- fastcgi spawning",
+								"\n\tport:", host->port,
+								"\n\tsocket", host->unixsocket,
+								"\n\tcurrent:", 1, "/", host->min_procs);
+					}
+					
 					if (fcgi_spawn_connection(srv, p, host, proc)) {
 						/* child died */
 						proc->state = PROC_STATE_DIED;
@@ -2805,6 +2838,7 @@ static handler_t fcgi_handle_fdevent(void *s, void *ctx, int revents) {
 			/* */
 			
 			
+			joblist_append(srv, con);
 			return HANDLER_FINISHED;
 		}
 	}
@@ -2858,6 +2892,7 @@ static handler_t fcgi_handle_fdevent(void *s, void *ctx, int revents) {
 			
 			connection_set_state(srv, con, CON_STATE_ERROR);
 			fcgi_connection_close(srv, hctx);
+			joblist_append(srv, con);
 		}
 	} else if (revents & FDEVENT_ERR) {
 		log_error_write(srv, __FILE__, __LINE__, "s", 
@@ -2867,6 +2902,7 @@ static handler_t fcgi_handle_fdevent(void *s, void *ctx, int revents) {
 
 		connection_set_state(srv, con, CON_STATE_ERROR);
 		fcgi_connection_close(srv, hctx);
+		joblist_append(srv, con);
 	}
 	
 	return HANDLER_FINISHED;
