@@ -280,12 +280,12 @@ static int http_response_parse_range(server *srv, connection *con) {
 	for (s = con->request.http_range, error = 0;
 	     !error && *s && NULL != (minus = strchr(s, '-')); ) {
 		char *err;
-		long la, le;
+		off_t la, le;
 		
 		if (s == minus) {
 			/* -<stop> */
 			
-			le = strtol(s, &err, 10);
+			le = strtoll(s, &err, 10);
 			
 			if (le == 0) {
 				/* RFC 2616 - 14.35.1 */
@@ -311,7 +311,7 @@ static int http_response_parse_range(server *srv, connection *con) {
 		} else if (*(minus+1) == '\0' || *(minus+1) == ',') {
 			/* <start>- */
 			
-			la = strtol(s, &err, 10);
+			la = strtoll(s, &err, 10);
 			
 			if (err == minus) {
 				/* ok */
@@ -338,10 +338,10 @@ static int http_response_parse_range(server *srv, connection *con) {
 		} else {
 			/* <start>-<stop> */
 			
-			la = strtol(s, &err, 10);
+			la = strtoll(s, &err, 10);
 			
 			if (err == minus) {
-				le = strtol(minus+1, &err, 10);
+				le = strtoll(minus+1, &err, 10);
 				
 				/* RFC 2616 - 14.35.1 */
 				if (la > le) {
@@ -657,6 +657,7 @@ static int http_list_directory(server *srv, connection *con, buffer *dir) {
 	char datebuf[sizeof("2005-Jan-01 22:23:24")];
 	size_t k;
 	const char *content_type;
+	long name_max;
 #ifdef HAVE_XATTR
 	char attrval[128];
 	int attrlen;
@@ -667,8 +668,14 @@ static int http_list_directory(server *srv, connection *con, buffer *dir) {
 
 	i = dir->used - 1;
 	if (i <= 0) return -1;
+
+#ifdef HAVE_PATHCONF
+	name_max = pathconf(dir->ptr, _PC_NAME_MAX);
+#else
+	name_max = NAME_MAX;
+#endif
 	
-	path = malloc(i + NAME_MAX + 1);
+	path = malloc(i + name_max + 1);
 	assert(path);
 	strcpy(path, dir->ptr);
 	path_file = path + i;
@@ -704,7 +711,7 @@ static int http_list_directory(server *srv, connection *con, buffer *dir) {
 		 *       so this should actually not be a buffer-overflow-risk
 		 */
 		i = strlen(dent->d_name);
-		if (i > NAME_MAX)
+		if (i > name_max)
 			continue;
 		memcpy(path_file, dent->d_name, i + 1);
 		if (stat(path, &st) != 0)
@@ -938,7 +945,7 @@ handler_t http_response_prepare(server *srv, connection *con) {
 		
 		
 		buffer_copy_string_buffer(srv->tmp_buf, con->uri.path_raw);
-		buffer_urldecode(srv->tmp_buf);
+		buffer_urldecode_path(srv->tmp_buf);
 		buffer_path_simplify(con->uri.path, srv->tmp_buf);
 
 		if (con->conf.log_request_handling) {
@@ -1036,11 +1043,16 @@ handler_t http_response_prepare(server *srv, connection *con) {
 				buffer_append_string_buffer(con->physical.path, con->physical.rel_path);
 			}
 		}
+		/* the docroot plugins might set the servername, if they don't we take http-host */
+		if (buffer_is_empty(con->server_name)) {
+			buffer_copy_string_buffer(con->server_name, con->uri.authority);
+		}
 		if (con->conf.log_request_handling) {
 			log_error_write(srv, __FILE__, __LINE__,  "s",  "-- logical -> physical");
 			log_error_write(srv, __FILE__, __LINE__,  "sb", "Doc-Root     :", con->physical.doc_root);
 			log_error_write(srv, __FILE__, __LINE__,  "sb", "Rel-Path     :", con->physical.rel_path);
 			log_error_write(srv, __FILE__, __LINE__,  "sb", "Path         :", con->physical.path);
+			log_error_write(srv, __FILE__, __LINE__,  "sb", "Server-Name  :", con->server_name);
 		}
 	}
 	
